"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onRenderBody = void 0;

var _react = _interopRequireDefault(require("react"));

var _terser = _interopRequireDefault(require("terser"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactComponents = require("@visiosto/react-components");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function setColorsByTheme() {
  var colors = '🌈';
  var colorModeKey = '🔑';
  var colorModeCssProp = '⚡️';
  var mediaQuery = window.matchMedia('(prefers-color-scheme: dark)');
  var prefersDarkScheme = mediaQuery.matches;
  var persistedPreference = localStorage.getItem(colorModeKey);
  var colorMode = 'light';
  var hasUsedToggle = false;

  if (hasUsedToggle) {
    colorMode = persistedPreference;
  } else {
    colorMode = prefersDarkScheme ? 'dark' : 'light';
  }

  var root = document.documentElement;
  var invertedColorMode = colorMode === 'dark' ? 'light' : 'dark';
  root.style.setProperty(colorModeCssProp, colorMode);
  Object.entries(colors).forEach(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        name = _ref2[0],
        colorByTheme = _ref2[1];

    var cssVarName = "--color-".concat(name);
    root.style.setProperty(cssVarName, colorByTheme[colorMode]);
    root.style.setProperty("".concat(cssVarName, "-inverted"), colorByTheme[invertedColorMode]);
  });
}

var magicScriptTagPropTypes = {
  colors: _propTypes["default"].object.isRequired
};

function MagicScriptTag(_ref3) {
  var colors = _ref3.colors;
  var boundFn = String(setColorsByTheme).replace("'🌈'", JSON.stringify(colors)).replace('🔑', _reactComponents.colorModeKey).replace('⚡️', _reactComponents.initialColorModeCSSProp);
  var calledFunction = "(".concat(boundFn, ")()");
  calledFunction = _terser["default"].minify(calledFunction).code;
  return _react["default"].createElement("script", {
    dangerouslySetInnerHTML: {
      __html: calledFunction
    }
  });
}

MagicScriptTag.propTypes = magicScriptTagPropTypes;
var fallbackStylesPropTypes = {
  colors: _propTypes["default"].object.isRequired
};

function FallbackStyles(_ref4) {
  var colors = _ref4.colors;
  var cssVariableString = Object.entries(colors).reduce(function (acc, _ref5) {
    var _ref6 = _slicedToArray(_ref5, 2),
        name = _ref6[0],
        colorByTheme = _ref6[1];

    return "".concat(acc, "\n--color-").concat(name, ": ").concat(colorByTheme.light, ";\n--color-").concat(name, "-inverted: ").concat(colorByTheme.dark, ";");
  }, '');
  var wrappedInSelector = "html { ".concat(cssVariableString, " }");
  return _react["default"].createElement("style", null, wrappedInSelector);
}

FallbackStyles.propTypes = fallbackStylesPropTypes;

var onRenderBody = function addColorThemeStylesOnRenderBody(_ref7, _ref8) {
  var setPreBodyComponents = _ref7.setPreBodyComponents,
      setHeadComponents = _ref7.setHeadComponents;
  var colors = _ref8.colors;
  setHeadComponents(_react["default"].createElement(FallbackStyles, {
    key: "color-scheme-fallback-styles",
    colors: colors
  }));
  setPreBodyComponents(_react["default"].createElement(MagicScriptTag, {
    key: "color-scheme-magic-script-tag",
    colors: colors
  }));
};

exports.onRenderBody = onRenderBody;